#include "CFileIO.h"

CFileIO::CFileIO()
{
	m_hFile = INVALID_HANDLE_VALUE;
}
CFileIO::~CFileIO()
{
	CloseFile();
}
BOOL CFileIO::CreateNewFile(LPSTR lpFileName)
{
	return CreateFile(lpFileName,GENERIC_READ | GENERIC_WRITE,FILE_SHARE_READ,CREATE_NEW);

}
BOOL CFileIO::OpenFile(LPSTR lpFileName)
{
	return CreateFile(lpFileName,GENERIC_READ | GENERIC_WRITE,FILE_SHARE_READ,OPEN_EXISTING);
}

BOOL CFileIO::CreateFile(LPSTR lpFileName,DWORD dwDesiredAccess,DWORD dwShareMode,DWORD dwCreationDisposition)
{
	m_hFile = ::CreateFile(lpFileName,dwDesiredAccess,dwShareMode,NULL,dwCreationDisposition,FILE_ATTRIBUTE_NORMAL,NULL);
	
	return IsOpened();
}
BOOL CFileIO::CloseFile(void)
{

	HANDLE hf = m_hFile;
	if (IsOpened())
	{
		m_hFile = INVALID_HANDLE_VALUE;
		return CloseHandle(hf);
	}
	return FALSE;
}
BOOL CFileIO::ReadFile(CBuffer& rBuffer)
{
	DWORD dwRead;
	
	if (IsOpened == FALSE)
		return FALSE;

	if ( ::ReadFile(m_hFile,rBuffer.GetPtr(),rBuffer.GetBufferSize(),&dwRead,NULL) )
	{
		rBuffer.SetDataSize(dwRead);
		return TRUE;
	}

	return FALSE;
}
BOOL CFileIO::WriteFile(CBuffer& rBuffer)
{
	return WriteFile(rBuffer.GetPtr(),rBuffer.GetDataSize());
}

DWORD CFileIO::ReadFile(LPVOID lpBuffer,DWORD nNumberOfBytesToRead)
{
	DWORD dwRead;
	
	if (IsOpened == FALSE)
		return NULL;

	if ( ::ReadFile(m_hFile,lpBuffer,nNumberOfBytesToRead,&dwRead,NULL) )
		return dwRead;

	return NULL;
}
BOOL CFileIO::WriteFile(LPCVOID lpBuffer,DWORD nNumberOfBytesToWrite)
{
	DWORD dwWritten;
	BOOL bRet;
	
	if (IsOpened == FALSE)
		return FALSE;
	
	bRet = ::WriteFile(m_hFile,lpBuffer,nNumberOfBytesToWrite,&dwWritten,NULL);

	if ( dwWritten == nNumberOfBytesToWrite && bRet != FALSE )
		return TRUE;

	return FALSE;
}
BOOL CFileIO::IsOpened(void)
{
if (m_hFile == INVALID_HANDLE_VALUE || m_hFile == NULL )
		return FALSE;
return TRUE;
}

BOOL  CFileIO::SetFilePointer(LONG lDistanceToMove)
{
 	if (!IsOpened())
		return FALSE;

	if (::SetFilePointer(m_hFile,lDistanceToMove,NULL,FILE_BEGIN) != INVALID_SET_FILE_POINTER )
		return TRUE;

return FALSE;
}
DWORD CFileIO::GetFilePointer(void)
{
	if (IsOpened())
		return ::SetFilePointer(m_hFile, 0, NULL, FILE_CURRENT);

	return NULL;
}
HANDLE CFileIO::GetHandle(void)
{
		return m_hFile;
}
DWORD CFileIO::GetFileSize(void)
{
	DWORD dwFileSize = ::GetFileSize(m_hFile,NULL);

	// most programs don't want empty file
	if ( dwFileSize== INVALID_FILE_SIZE )
		dwFileSize = NULL;

return dwFileSize;
}


BOOL CFileIO::OpenReadOnly(LPSTR lpFileName)
{
   return CreateFile(lpFileName,GENERIC_READ,FILE_SHARE_READ | FILE_SHARE_WRITE,OPEN_EXISTING);
}

BOOL CFileIO::OpenReadWrite(LPSTR lpFileName)
{
	return CreateFile(lpFileName,GENERIC_READ | GENERIC_WRITE,FILE_SHARE_READ | FILE_SHARE_WRITE,OPEN_EXISTING);
}
BOOL CFileIO::OpenWriteOnly(LPSTR lpFileName)
{
	return CreateFile(lpFileName,GENERIC_WRITE,FILE_SHARE_READ | FILE_SHARE_WRITE,OPEN_EXISTING);
}

BOOL  CFileIO::SeekToBOF(void)
{
return SetFilePointer(NULL);
}
BOOL  CFileIO::SeekToEOF(void)
{
return SetFilePointer(GetFileSize());
}
BOOL  CFileIO::SetEndOfFile(void)
{
	return ::SetEndOfFile(m_hFile);
}
BOOL CFileIO::CreateNewFile(CAnsiString& astrFileName)
{
	return CreateNewFile(astrFileName());
}
BOOL CFileIO::OpenFile(CAnsiString& astrFileName)
{
		return OpenFile(astrFileName());

}
BOOL CFileIO::OpenReadOnly(CAnsiString& astrFileName)
{
		return OpenReadOnly(astrFileName());

}
BOOL CFileIO::OpenReadWrite(CAnsiString& astrFileName)
{
		return OpenReadWrite(astrFileName());

}
BOOL CFileIO::OpenWriteOnly(CAnsiString& astrFileName)
{
		return OpenWriteOnly(astrFileName());

}
/*
This file is a part of CIF.
Project Core Information Foundation (CIF).
Developed by Muhammad Arshad Latti.
Location Sargodha (Pakistan).
arshadlatti@gmail.com
http://arshadlatti.angelfire.com/
*/
